/*
    Header file for Linux PIC84 programmer
    Copyright (C) 1994-1998 by Brian C. Lane (brian@nexuscomputing.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdio.h>
#include <curses.h>
#include <unistd.h>

#define flushall() fflush(NULL)


#define VERSION " Linux PIC84 programmer     v2.2           Copyright 1994-1998 by Brian C. Lane "

#define	PIC16C84	0

/* How to genericly handle the ports, lines, and polarities? */
struct _pconfig
{
  int	port;				/* /dev/lpX		 	*/
  int	colors;				/* Color support 1 or 0		*/
  int	PIC_type;			/* Default PIC type		*
  					 * 0 = PIC16C84			*
  					 * Others to be defined		*/
  uint	CFaddr;				/* Config Fuses Address 0x2007	*/
  uint	IDaddr;				/* ID Memory address 0x2000	*/
  uint	EEaddr;				/* EEPROM address 0x2100	*/
  int	VPP_pin;			/* Pin for VPP control		*/
  int	VPP_pol;			/* Polarity 0=inverted 1=normal	*/
  int	VDD_pin;			/* Pin for Vdd control		*/
  int	VDD_pol;			/* Polarity 0=inverted 1=normal	*/
  int	CLK_pin;			/* Pin for Clock control	*/
  int	CLK_pol;			/* Polarity 0=inverted 1=normal	*/
  int	DATAO_pin;			/* Pin for Data to PIC control	*/
  int	DATAO_pol;			/* Polarity 0=inverted 1=normal	*/
  int	DATAI_pin;			/* Pin for Data from PIC control*/
  int	DATAI_pol;			/* Polarity 0=inverted 1=normal	*/
};

/* Structure to hold all the data about the currently loaded processor	*/
#define MAXPICSIZE 65535

struct _pic
{
  unsigned int	mem[MAXPICSIZE];	/* up to 16 bit words		*/
};


int init_port();
int verify_pic( WINDOW * );
int program_pic( WINDOW * );
int read_pic( WINDOW * );
int readihex( FILE *, unsigned int *, int *, int * );
int writeihex16( FILE *, unsigned int *, int, int );
int writeiend16( FILE * );
void attr_clear(WINDOW *, int, int, chtype);
void show_err( char *fmt, ... );
int inbit();
int vppon();
int vppoff();
int vddon();
int vddoff();
int clkhi();
int clklo();
int outhi();
int outlo();

/* Memory storage functions */
void	init_pic();
